@@ -80,7 +80,7 @@ class HttpTransit:
         RESP = {}
 
         # Generar la metadata y el Key de la operacion
-        Key_op, meta = self.__create_meta()
+        Key_op, meta = self.__create_meta(id)
 
         # Lanzar el metodo
         self._message(meta)
@@ -203,7 +203,7 @@ class HttpTransit:
         """
         pass
 
-    def __create_meta(self):
+    def __create_meta(self, id_resource=None):
         """
             Metodo para la generacion de la metadata
         """
@@ -233,7 +233,7 @@ class HttpTransit:
                 "time": None,
                 "from": self.__hostname,
                 "method": request.method,
-                "uuid": None,
+                "uuid": id_resource,
                 "callbacks": [{"method": request.method, "name": self._topic}],
                 "deviceType": "SERVER",
                 "hostname": self.__hostname,
