@@ -18,6 +18,7 @@ from abc import abstractmethod, ABC
 from .options import Options
 from .Worker import Worker
 from .Fork import Fork
+from .ForkHttp import ForkHttp
 from .ErrorMs import ErrorMs
 import time
 from .Util import validForksConf, getItemBy
@@ -133,7 +134,19 @@ class Microservices(BaseClass, ABC):
         else:
             self.logs.info(
                 'Se Inicia el servicio con soporte para bifurcaciones')
-            self.__APP = Fork(self.__TOPIC__)
+
+            if not os.environ.get('REST_ENABLED', None) is None:
+                if os.environ.get('URL_ENDPOINT_SERVICES', None) is None:
+                    self.logs.error(
+                        "No se proporciono el valor para URL_ENDPOINT_SERVICES"
+                    )
+                    sys.exit(-1)
+                else:
+                    self.logs.info("Se inicia el soporte de Fork Http")
+                    self.__APP = ForkHttp(self.__TOPIC__)
+            else:
+                self.__APP = Fork(self.__TOPIC__)
+
             self.___isForks = True
 
         # Inicializar el redis
@@ -584,7 +597,7 @@ class Microservices(BaseClass, ABC):
             if confForks is None:
                 self.__APP = Worker(self.__TOPIC__)
             else:
-                self.__APP = Fork(self.__TOPIC__)
+                # self.__APP = Fork(self.__TOPIC__)
                 self.__APP.confForks(confForks)
 
             # Indicar si es una bifurcacion
@@ -834,7 +847,7 @@ class Microservices(BaseClass, ABC):
                 mt = cllbs.get('method')
 
                 if self.__TOPIC__ == tp and original_method == mt:
-                    self.logs.warn('Repetition event prevented')
+                    self.logs.warning('Repetition event prevented')
                 else:
                     # Agregar al arreglo
                     dataResponse['metadata']['callbacks'].append({
@@ -955,7 +968,7 @@ class Microservices(BaseClass, ABC):
                         "data": {
                             "response": {
                                 "code": errorCode,
-                                "framework": version,
+                                "framework": f'mscoppel:{version}',
                                 "hostname": self.__HOSTNAME,
                                 "userMessage": "Smoke test"
                             }
