@@ -49,7 +49,10 @@ class Options:
 
         # Validar si es Nats
         if os.environ.get('NATS', None) is not None:
-            self.isNats = True
+            if len(os.environ.get('NATS')) > 0:
+                self.isNats = True
+            else:
+                self.isNats = False
         elif len(re.findall(r'^nats.*', hosts[0])) > 0:
             self.isNats = True
         else:
